==> qt6-declarative-6.9.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6QmlAssetDownloader/Qt6QmlAssetDownloaderTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QmlAssetDownloader" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QmlAssetDownloader APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::QmlAssetDownloader PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libQt6QmlAssetDownloader.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QmlAssetDownloader )
list(APPEND _cmake_import_check_files_for_Qt6::QmlAssetDownloader "${_IMPORT_PREFIX}/lib/libQt6QmlAssetDownloader.a" )

# Import target "Qt6::QmlAssetDownloader_resources_1" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QmlAssetDownloader_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::QmlAssetDownloader_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELWITHDEBINFO ""
  IMPORTED_OBJECTS_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qml/Assets/Downloader/objects-RelWithDebInfo/QmlAssetDownloader_resources_1/.qt/rcc/qrc_qmake_Assets_Downloader_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::QmlAssetDownloader_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QmlAssetDownloader_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/Assets/Downloader/objects-RelWithDebInfo/QmlAssetDownloader_resources_1/.qt/rcc/qrc_qmake_Assets_Downloader_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-declarative-6.10.1-2-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6QmlAssetDownloader/Qt6QmlAssetDownloaderTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QmlAssetDownloader" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QmlAssetDownloader APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::QmlAssetDownloader PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libQt6QmlAssetDownloader.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QmlAssetDownloader )
list(APPEND _cmake_import_check_files_for_Qt6::QmlAssetDownloader "${_IMPORT_PREFIX}/lib/libQt6QmlAssetDownloader.a" )

# Import target "Qt6::QmlAssetDownloader_resources_1" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QmlAssetDownloader_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::QmlAssetDownloader_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELWITHDEBINFO ""
  IMPORTED_OBJECTS_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qml/Qt/labs/assetdownloader/objects-RelWithDebInfo/QmlAssetDownloader_resources_1/.qt/rcc/qrc_qmake_Qt_labs_assetdownloader_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::QmlAssetDownloader_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QmlAssetDownloader_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/Qt/labs/assetdownloader/objects-RelWithDebInfo/QmlAssetDownloader_resources_1/.qt/rcc/qrc_qmake_Qt_labs_assetdownloader_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
